"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpecifiedOutputDirectoryIsNotADirectory = exports.SpecifiedOutputDirectoryDoesNotExist = void 0;
const node_path_1 = __importDefault(require("node:path"));
const node_fs_1 = __importDefault(require("node:fs"));
function isErrnoException(err) {
    return typeof err === "object" && err instanceof Error;
}
class SpecifiedOutputDirectoryDoesNotExist extends Error {
    constructor(outDir) {
        super(`Specified output directory \`${outDir}\` does not exist.`);
    }
}
exports.SpecifiedOutputDirectoryDoesNotExist = SpecifiedOutputDirectoryDoesNotExist;
class SpecifiedOutputDirectoryIsNotADirectory extends Error {
    constructor(outDir) {
        super(`Specified output directory \`${outDir}\` is not a directory.`);
    }
}
exports.SpecifiedOutputDirectoryIsNotADirectory = SpecifiedOutputDirectoryIsNotADirectory;
function reporter(benchmark, { outDir = "/" } = {}) {
    try {
        const stat = node_fs_1.default.statSync(outDir);
        if (!stat.isDirectory()) {
            throw new SpecifiedOutputDirectoryIsNotADirectory(outDir);
        }
    }
    catch (error) {
        if (error instanceof SpecifiedOutputDirectoryIsNotADirectory) {
            throw error;
        }
        if (isErrnoException(error)) {
            switch (error.code) {
                case "ENOENT":
                    throw new SpecifiedOutputDirectoryDoesNotExist(outDir);
                default:
                    throw error;
            }
        }
        throw error;
    }
    benchmark.on("end", () => {
        node_fs_1.default.writeFileSync(node_path_1.default.join(outDir, `${Date.now()}-results.json`), JSON.stringify({
            runResults: Array.from(benchmark.results.entries()).map(([k, v]) => ({
                run: k,
                results: v,
            })),
        }));
    });
}
exports.default = reporter;
